@@ -47,24 +47,22 @@ from sklearn.svm import SVR, LinearSVR
 from sklearn.tree import DecisionTreeRegressor
 from sklearn.neighbors import KNeighborsRegressor
 from xgboost import XGBRegressor
-
-from sklearn.experimental import enable_halving_search_cv  # noqa
-from sklearn.model_selection import RandomizedSearchCV, HalvingRandomSearchCV
-import multiprocessing
+from sklearn.experimental import enable_halving_search_cv
+from sklearn.model_selection import HalvingRandomSearchCV
 import numpy as np
 
 
 class Classifiers:
     def __init__(self,
                  k_folds=5,
-                 n_jobs=multiprocessing.cpu_count() // 2,
+                 n_jobs=2,
                  verbose=1):
         self.models = [
             GaussianNB(),
             HalvingRandomSearchCV(
                 estimator=BernoulliNB(),
                 param_distributions={
-                    'alpha': [1e-3, 1e-2, 1e-1, 1., 10., 100.],
+                    'alpha': [1e-3, 1e-2, 1e-1, 1., 10., 20.],
                     'fit_prior': [True, False]
                 },
                 cv=k_folds,
@@ -87,12 +85,11 @@ class Classifiers:
                 ExtraTreesClassifier(n_jobs=n_jobs,
                                      random_state=0),
                 param_distributions={
-                    'n_estimators': np.arange(start=100, stop=1001, step=200),
-                    'criterion': ["gini", "entropy"],
-                    'max_features': np.arange(0.05, 1.01, 0.05),
-                    'min_samples_split': range(2, 21),
-                    'min_samples_leaf': range(1, 21),
-                    'bootstrap': [True, False]
+                    'n_estimators': [100, 300],
+                    'max_depth': [8, 15, None],
+                    'max_features': ['log2', 'sqrt'],
+                    'min_samples_split': [2, 5, 10, 15, 20],
+                    'min_samples_leaf': [1, 2, 5, 10],
                 },
                 cv=k_folds,
                 random_state=0,
@@ -102,8 +99,7 @@ class Classifiers:
             HalvingRandomSearchCV(
                 KNeighborsClassifier(n_jobs=n_jobs),
                 param_distributions={
-                    'n_neighbors': range(2, 101),
-                    'weights': ["uniform", "distance"],
+                    'n_neighbors': [2, 4, 8, 10],
                     'p': [1, 2]
                 },
                 cv=k_folds,
@@ -116,9 +112,22 @@ class Classifiers:
                                    random_state=0),
                 param_distributions={
                     'penalty': ["l1", "l2"],
-                    'C': [1e-2, 1e-1, 0.5, 1., 5., 10., 15., 20., 25.],
-                    'dual': [True, False],
-                    'max_iter': np.arange(start=100, stop=301, step=100)
+                    'C': np.logspace(0, 3, 4),
+                    'max_iter': np.arange(start=100, stop=1001, step=500)
+                },
+                cv=k_folds,
+                random_state=0,
+                verbose=verbose,
+                n_jobs=n_jobs
+            ),
+            HalvingRandomSearchCV(
+                LogisticRegression(n_jobs=n_jobs,
+                                   random_state=0),
+                param_distributions={
+                    'penalty': ["l2"],
+                    'solver': ['newton-cg', 'saga', 'sag'],
+                    'C': np.logspace(0, 3, 4),
+                    'max_iter': np.arange(start=100, stop=1001, step=500)
                 },
                 cv=k_folds,
                 random_state=0,
@@ -134,25 +143,37 @@ class Classifiers:
                     'penalty': ['elasticnet'],
                     'alpha': [0.0, 0.01, 0.001],
                     'learning_rate': ['invscaling', 'constant'],
-                    'fit_intercept': [True, False],
                     'l1_ratio': [0.25, 0.0, 1.0, 0.75, 0.5],
                     'eta0': [0.1, 1.0, 0.01],
-                    'power_t': [0.5, 0.0, 1.0, 0.1, 100.0, 10.0, 50.0]
+                    'power_t': [0.5, 0.0, 1.0, 0.1, 10.0, 50.0]
                 },
                 cv=k_folds,
                 random_state=0,
                 verbose=verbose,
                 n_jobs=n_jobs
             ),
+            HalvingRandomSearchCV(
+                LinearSVC(random_state=0),
+                param_distributions={
+                    'penalty': ["l2"],
+                    'dual': [True],
+                    'max_iter': np.arange(start=100, stop=1001, step=500),
+                    'tol': [1e-3, 1e-2, 1e-1],
+                    'C': np.logspace(0, 3, 4),
+                },
+                random_state=0,
+                verbose=verbose,
+                cv=k_folds,
+                n_jobs=n_jobs
+            ),
             HalvingRandomSearchCV(
                 LinearSVC(random_state=0),
                 param_distributions={
                     'penalty': ["l1", "l2"],
-                    'loss': ["hinge", "squared_hinge"],
-                    'dual': [True, False],
-                    'tol': [1e-5, 1e-4, 1e-3, 1e-2, 1e-1],
-                    'C': [1e-4, 1e-3, 1e-2, 1e-1, 0.5, 1., 5., 10., 15., 20.,
-                          25.]
+                    'max_iter': np.arange(start=100, stop=1001, step=500),
+                    'dual': [False],
+                    'tol': [1e-3, 1e-2, 1e-1],
+                    'C': np.logspace(0, 3, 4)
                 },
                 random_state=0,
                 verbose=verbose,
@@ -164,12 +185,10 @@ class Classifiers:
                     n_jobs=n_jobs,
                     random_state=0),
                 param_distributions={
-                    'n_estimators': np.arange(start=100, stop=1001, step=200),
-                    'criterion': ["gini", "entropy"],
-                    'max_features': np.arange(0.05, 1.01, 0.05),
-                    'min_samples_split': range(2, 21),
-                    'min_samples_leaf': range(1, 21),
-                    'bootstrap': [True, False]
+                    'n_estimators': [100, 300],
+                    'max_features': ['log2', 'sqrt'],
+                    'min_samples_split': [2, 5, 10, 15, 20],
+                    'min_samples_leaf': [1, 2, 5, 10],
                 },
                 cv=k_folds,
                 random_state=0,
@@ -179,13 +198,8 @@ class Classifiers:
             HalvingRandomSearchCV(
                 GradientBoostingClassifier(random_state=0),
                 param_distributions={
-                    'n_estimators': np.arange(start=100, stop=1001, step=200),
+                    'n_estimators': [100, 300],
                     'learning_rate': [1e-3, 1e-2, 1e-1, 0.5, 1.],
-                    'max_depth': range(1, 11),
-                    'min_samples_split': range(2, 21),
-                    'min_samples_leaf': range(1, 21),
-                    'subsample': np.arange(0.05, 1.01, 0.05),
-                    'max_features': np.arange(0.05, 1.01, 0.05)
                 },
                 cv=k_folds,
                 random_state=0,
@@ -196,10 +210,10 @@ class Classifiers:
                 XGBClassifier(n_jobs=n_jobs,
                               random_state=0),
                 param_distributions={
-                    'n_estimators': np.arange(start=100, stop=1001, step=200),
-                    'max_depth': range(1, 11),
+                    'n_estimators': [100, 300],
                     'learning_rate': [1e-3, 1e-2, 1e-1, 0.5, 1.],
-                    'subsample': np.arange(0.05, 1.01, 0.05),
+                    'min_child_weight': range(1, 21),
+                    'subsample': np.arange(0.05, 1.0, 0.05),
                     'min_child_weight': range(1, 21),
                 },
                 cv=k_folds,
@@ -211,7 +225,7 @@ class Classifiers:
                 DecisionTreeClassifier(random_state=0),
                 param_distributions={
                     'criterion': ["gini", "entropy"],
-                    'max_depth': range(1, 11),
+                    'max_depth': range(1, 21),
                     'min_samples_split': range(2, 21),
                     'min_samples_leaf': range(1, 21)
                 },
@@ -223,8 +237,14 @@ class Classifiers:
             HalvingRandomSearchCV(
                 MLPClassifier(random_state=0),
                 param_distributions={
-                    'max_iter': np.arange(start=100, stop=1001, step=100),
-                    'hidden_layer_sizes': [(10, 30, 10), (50, 50, 50), (50, 100, 50), (20,), (100,)],
+                    'max_iter': np.arange(start=100, stop=1001, step=500),
+                    'hidden_layer_sizes': [
+                        (10, 30, 10),
+                        (50, 50, 50),
+                        (50, 100, 50),
+                        (20,),
+                        (100,)
+                    ],
                     'activation': ['tanh', 'relu'],
                     'solver': ['sgd', 'adam'],
                     'alpha': [0.0001, 0.05],
@@ -241,15 +261,15 @@ class Classifiers:
 class Regressors:
     def __init__(self,
                  k_folds=5,
-                 n_jobs=multiprocessing.cpu_count() // 2,
+                 n_jobs=2,
                  verbose=1):
         self.models = [
             LinearRegression(n_jobs=n_jobs),
             HalvingRandomSearchCV(
                 estimator=ElasticNet(random_state=0),
                 param_distributions={
-                    'l1_ratio': np.arange(0.0, 1.01, 0.05),
-                    'tol': [1e-5, 1e-4, 1e-3, 1e-2, 1e-1]
+                    'l1_ratio': np.arange(0.0, 1.0, 0.05),
+                    'tol': [1e-3, 1e-2, 1e-1]
                 },
                 cv=k_folds,
                 verbose=verbose,
@@ -259,11 +279,11 @@ class Regressors:
             HalvingRandomSearchCV(
                 estimator=ExtraTreesRegressor(random_state=0),
                 param_distributions={
-                    'n_estimators': np.arange(start=100, stop=1001, step=200),
-                    'max_features': np.arange(0.05, 1.01, 0.05),
-                    'min_samples_split': range(2, 21),
-                    'min_samples_leaf': range(1, 21),
-                    'bootstrap': [True, False]
+                    'n_estimators': [100, 300],
+                    'max_depth': [8, 15, None],
+                    'max_features': ['log2', 'sqrt'],
+                    'min_samples_split': [2, 5, 10, 15, 20],
+                    'min_samples_leaf': [1, 2, 5, 10],
                 },
                 cv=k_folds,
                 verbose=verbose,
@@ -273,14 +293,13 @@ class Regressors:
             HalvingRandomSearchCV(
                 estimator=GradientBoostingRegressor(random_state=0),
                 param_distributions={
-                    'n_estimators': np.arange(start=100, stop=1001, step=200),
+                    'n_estimators': [100, 300],
                     'loss': ["ls", "lad", "huber", "quantile"],
                     'learning_rate': [1e-3, 1e-2, 1e-1, 0.5, 1.],
-                    'max_depth': range(1, 11),
-                    'min_samples_split': range(2, 21),
-                    'min_samples_leaf': range(1, 21),
-                    'subsample': np.arange(0.05, 1.01, 0.05),
-                    'max_features': np.arange(0.05, 1.01, 0.05),
+                    'max_depth': [8, 15, None],
+                    'max_features': ['log2', 'sqrt'],
+                    'min_samples_split': [2, 5, 10, 15, 20],
+                    'min_samples_leaf': [1, 2, 5, 10],
                     'alpha': [0.75, 0.8, 0.85, 0.9, 0.95, 0.99]
                 },
                 cv=k_folds,
@@ -291,7 +310,7 @@ class Regressors:
             HalvingRandomSearchCV(
                 estimator=AdaBoostRegressor(random_state=0),
                 param_distributions={
-                    'n_estimators': np.arange(start=100, stop=1001, step=200),
+                    'n_estimators': [100, 300],
                     'learning_rate': [1e-3, 1e-2, 1e-1, 0.5, 1.],
                     'loss': ["linear", "square", "exponential"]
                 },
@@ -315,8 +334,7 @@ class Regressors:
             HalvingRandomSearchCV(
                 estimator=KNeighborsRegressor(n_jobs=n_jobs),
                 param_distributions={
-                    'n_neighbors': range(2, 101),
-                    'weights': ["uniform", "distance"],
+                    'n_neighbors': [2, 4, 8, 10],
                     'p': [1, 2]
                 },
                 cv=k_folds,
@@ -327,7 +345,7 @@ class Regressors:
             HalvingRandomSearchCV(
                 estimator=Ridge(random_state=0),
                 param_distributions={
-                    'alpha': [0.001, 0.01, 0.1, 1, 10, 100, 1000]
+                    'alpha': [0.001, 0.01, 0.1, 1, 10, 100]
                 },
                 cv=k_folds,
                 verbose=verbose,
@@ -337,7 +355,7 @@ class Regressors:
             HalvingRandomSearchCV(
                 estimator=Lasso(random_state=0),
                 param_distributions={
-                    'alpha': [0.001, 0.01, 0.1, 1, 10, 100, 1000]
+                    'alpha': [0.001, 0.01, 0.1, 1, 10, 100]
                 },
                 cv=k_folds,
                 verbose=verbose,
@@ -347,7 +365,7 @@ class Regressors:
             HalvingRandomSearchCV(
                 estimator=LassoLars(random_state=0),
                 param_distributions={
-                    'alpha': [0.001, 0.01, 0.1, 1, 10, 100, 1000]
+                    'alpha': [0.001, 0.01, 0.1, 1, 10, 100]
                 },
                 cv=k_folds,
                 verbose=verbose,
@@ -359,11 +377,24 @@ class Regressors:
                 param_distributions={
                     'loss': ["epsilon_insensitive",
                              "squared_epsilon_insensitive"],
-                    'dual': [True, False],
-                    'tol': [1e-5, 1e-4, 1e-3, 1e-2, 1e-1],
-                    'C': [1e-4, 1e-3, 1e-2, 1e-1, 0.5, 1., 5., 10., 15., 20.,
-                          25., 30, 35, 50, 100, 200, 500, 1000],
-                    'epsilon': [1e-4, 1e-3, 1e-2, 1e-1, 1.]
+                    'dual': [True],
+                    'tol': [1e-3, 1e-2, 1e-1],
+                    'C': np.logspace(0, 3, 4),
+                    'epsilon': [1e-3, 1e-2, 1e-1, 1.]
+                },
+                cv=k_folds,
+                verbose=verbose,
+                n_jobs=n_jobs,
+                random_state=0
+            ),
+            HalvingRandomSearchCV(
+                estimator=LinearSVR(random_state=0),
+                param_distributions={
+                    'loss': ["squared_epsilon_insensitive"],
+                    'dual': [False],
+                    'tol': [1e-3, 1e-2, 1e-1],
+                    'C': np.logspace(0, 3, 4),
+                    'epsilon': [1e-3, 1e-2, 1e-1, 1.]
                 },
                 cv=k_folds,
                 verbose=verbose,
@@ -375,11 +406,10 @@ class Regressors:
                     n_jobs=n_jobs,
                     random_state=0),
                 param_distributions={
-                    'n_estimators': np.arange(start=100, stop=1001, step=200),
-                    'max_features': np.arange(0.05, 1.01, 0.05),
-                    'min_samples_split': range(2, 21),
-                    'min_samples_leaf': range(1, 21),
-                    'bootstrap': [True, False]
+                    'n_estimators': [100, 300],
+                    'max_features': ['log2', 'sqrt', ],
+                    'min_samples_split': [2, 5, 10, 15, 20],
+                    'min_samples_leaf': [1, 2, 5, 10],
                 },
                 cv=k_folds,
                 verbose=verbose,
@@ -391,12 +421,11 @@ class Regressors:
                     n_jobs=n_jobs,
                     random_state=0),
                 param_distributions={
-                    'n_estimators': np.arange(start=100, stop=1001, step=200),
-                    'max_depth': range(1, 11),
+                    'n_estimators': [100, 300],
                     'learning_rate': [1e-3, 1e-2, 1e-1, 0.5, 1.],
-                    'subsample': np.arange(0.05, 1.01, 0.05),
                     'min_child_weight': range(1, 21),
-                    'objective': ['reg:squarederror']
+                    'subsample': np.arange(0.05, 1.0, 0.05),
+                    'min_child_weight': range(1, 21),
                 },
                 cv=k_folds,
                 verbose=verbose,
@@ -410,10 +439,9 @@ class Regressors:
                     'penalty': ['elasticnet'],
                     'alpha': [0.0, 0.01, 0.001],
                     'learning_rate': ['invscaling', 'constant'],
-                    'fit_intercept': [True, False],
                     'l1_ratio': [0.25, 0.0, 1.0, 0.75, 0.5],
                     'eta0': [0.1, 1.0, 0.01],
-                    'power_t': [0.5, 0.0, 1.0, 0.1, 100.0, 10.0, 50.0]
+                    'power_t': [0.5, 0.0, 1.0, 0.1, 10.0, 50.0]
                 },
                 cv=k_folds,
                 verbose=verbose,
